pub enum CompileError {
InvalidPlaceholder {
route: String,
placeholder: String,
reason: String,
},
UnknownKind {
route: String,
name: String,
kind: String,
},
DuplicatePlaceholder {
route: String,
name: String,
},
InvalidRegex {
route: String,
source: String,
},
UndeclaredPlaceholder {
route: String,
name: String,
location: String,
},
UnbalancedBraces {
route: String,
location: String,
},
}Expand description
Compile-time error from compile.
Variants
InvalidPlaceholder
A placeholder spec was malformed, e.g. {na me} or {:int}.
UnknownKind
An unknown placeholder kind, e.g. {name:foo}.
DuplicatePlaceholder
The same placeholder name was declared twice in the same pattern.
InvalidRegex
The generated regex failed to compile (very unlikely — usually an indication of weird literal characters that escaped wrong).
UndeclaredPlaceholder
A {name} appeared in the target/header template but was never
declared in the match pattern.
UnbalancedBraces
Unbalanced braces in pattern or template.